#
# spec file for package python-flux-local
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flux-local
Version:        7.5.6
Release:        1.1
Summary:        Set of tools for managing a flux gitops repository
License:        Apache-2.0
URL:            https://github.com/allenporter/flux-local
Source:         https://files.pythonhosted.org/packages/source/f/flux-local/flux_local-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
#
BuildRequires:  %{python_module aiofiles >= 24.1.0}
BuildRequires:  %{python_module GitPython >= 3.1.44}
BuildRequires:  %{python_module PyYAML >= 6.0.2}
BuildRequires:  %{python_module mashumaro >= 3.16}
BuildRequires:  %{python_module nest-asyncio >= 1.6.0}
BuildRequires:  %{python_module oras >= 0.2.37}
BuildRequires:  %{python_module python-slugify >= 8.0.4}
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 8.3.5}
BuildRequires:  %{python_module pytest-asyncio >= 1.0.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-GitPython >= 3.1.44
Requires:       python-PyYAML >= 6.0.2
Requires:       python-aiofiles >= 24.1.0
Requires:       python-mashumaro >= 3.16
Requires:       python-nest-asyncio >= 1.6.0
Requires:       python-oras >= 0.2.37
Requires:       python-python-slugify >= 8.0.4
# Note: flux-local provides repo testing using pytest
Requires:       python-pytest >= 8.3.5
Requires:       python-pytest-asyncio >= 1.0.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
flux-local is a python library and set of tools for managing a flux gitops
repository, with validation steps to help improve quality of commits, PRs, and
general local testing.

%prep
%autosetup -p1 -n flux_local-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/flux-local
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative flux-local

%postun
%python_uninstall_alternative flux-local

%files %{python_files}
%python_alternative %{_bindir}/flux-local
%{python_sitelib}/flux_local
%pycache_only %{python_sitelib}/flux_local/__pycache__/
%{python_sitelib}/flux_local-%{version}.dist-info

%changelog
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.5.6:
  * Fix a bug when diffing OCIRepository changes used by multiple
    HelmReleases by @allenporter in #948
  * Add a second app-template for testing diffs by @allenporter in
    [#946]
  * Update app-template test charts by @allenporter in #947
* Sun Jun 15 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.5.5:
  * What's Changed
  - Improve error messages in image extraction by @allenporter in
    [#944]
  - fix: upgrade helm to 3.18.1 by @onedr0p in #928
  - pin oras in requirements.txt (avoid bug in oras 0.2.34) by
    @samholton in #943
  * Other dependency updates
  - chore(deps): update fluxcd/flux2 action to v2.6.0 by
    @renovate in #929
  - chore(deps): update ghcr.io/fluxcd/flux-cli docker tag to
    v2.6.0 by @renovate in #930
  - chore(deps): update dependency oras to v0.2.33 by @renovate
    in #933
  - chore(deps): update dependency pdoc to v15.0.4 by @renovate
    in #940
  - chore(deps): update fluxcd/flux2 action to v2.6.1 by
    @renovate in #934
  - chore(deps): update ghcr.io/fluxcd/flux-cli docker tag to
    v2.6.1 by @renovate in #935
  - chore(deps): update dependency pytest to v8.4.0 by @renovate
    in #937
  - chore(deps): update dependency mypy to v1.16.0 by @renovate
    in #932
  - chore(deps): update dependency typing-extensions to v4.14.0
    by @renovate in #936
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.11.13 by @renovate in
    [#931]
  - chore(deps): update ubuntu docker tag to noble-20250529 by
    @renovate in #939
  - chore(deps): update dependency oras to v0.2.35 by @renovate
    in #941
* Thu May 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.5.4:
  * fix: downgrade helm to 3.17.3 by @onedr0p in #926
* Mon May 26 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.5.3:
  * What's Changed
  - Revert uv for project publish by @allenporter in #925
  * Experimental non-released features
  - Add an orchestration layer and flux-local shell by
    @allenporter in #911
  - Improve reconcile for kustomize controller by @allenporter in
    [#912]
  - Add new API watch API to the store by @allenporter in #913
  - Add a background task API to the task service by @allenporter
    in #915
  - Move kustomize controller to watch API by @allenporter in
    [#916]
  - Add a dependency watcher by @allenporter in #917
  - Add a method to the store to watch for a specific object
    existing by @allenporter in #918
  - Remove dead code from watcher by @allenporter in #919
  - Add co-pilot instructions by @allenporter in #921
  - Add suport for watching objects without a status by
    @allenporter in #920
  - Update design documentation by @allenporter in #922
  - Add flux-local build ks-new to use new experimental
    orchestrator by @allenporter in #923
  * Developer udpates
  - chore(deps): update dependency pytest-asyncio to v1 by
    @renovate in #914
- update to 7.5.2:
  * Fix style errors form pre-commit by @allenporter in #909
  * Rollback Helm to 3.17.3 by @allenporter in #910
- update to 7.5.1:
  * Improve handling of relative paths by @allenporter in #874
  * Update CONTRIBUTING to recommend uv by @allenporter in #875
  * Propose a new design for the system by @allenporter in #876
  * Update python install process using uv to improve speed by
    @allenporter in #877
  * Update actions to python3.13 and latest astral by @allenporter
    in #879
  * Add a foundational storage module by @allenporter in #880
  * Add an initial source controller by @allenporter in #881
  * Fix tests by setgin a fixed chart version for podinfo by
    @allenporter in #889
  * chore(deps): update dependency types-pyyaml to v6.0.12.20250516
    by @renovate in #891
  * chore(deps): update dependency ruff to v0.11.10 by @renovate in
    [#885]
  * chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.11.10 by @renovate in #886
  * chore(deps): update codecov/codecov-action action to v5.4.3 by
    @renovate in #887
  * chore(deps): update docker.io/bitnami/kubectl docker tag to
    v1.33.1 by @renovate in #888
  * chore(deps): update dependency types-aiofiles to
    v24.1.0.20250516 by @renovate in #890
  * Ignore virtual environments with diagnostics command by
    @allenporter in #892
  * Add a Kustomization Controller by @allenporter in #893
  * Simplify controllers and cleanup pydoc by @allenporter in #894
  * Add a HelmController by @allenporter in #895
  * Improve git support in the source controller by @allenporter in
    [#896]
  * Improve OCIRepository version handling by @allenporter in #897
  * Improve Artifact support for OCI Artfacts in new controllers by
    @allenporter in #898
  * Rename source_controller to controller by @allenporter in #900
  * Update kustomize controller to apply objects by @allenporter in
    [#901]
  * Update helm controller to apply objects to the cluster by
    @allenporter in #902
  * chore(deps): update dependency python-slugify to v8.0.4 by
    @renovate in #899
  * Add a task service by @allenporter in #903
  * Implement a task context manager by @allenporter in #904
  * Use task service to simpilfy tests waiting for callbacks to run
    by @allenporter in #905
  * Fix for a temporary default Helm registry config for some helm
    versions by @allenporter in #907
  * Set pytest verbose flag in action when debug is enabled by
    @allenporter in #908
* Sun May  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.5.0:
  * Fix "RuntimeError: Event loop is closed" by @allenporter in #872
  * Fix helm valuesFrom escape dot notation by @Lingkar in #871
  * Allow --sources to operate on a GitRepository source and allow it
    to be external to the cluster by @allenporter in #873
* Fri Apr 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.4.0:
  * What's Changed
  - Update install instructions by @allenporter in #858
  - Add support for targetNamespace by @weisdd in #866
* Fri Mar 21 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.3.0:
  * What's Changed
  - Add support for HelmRelease disableSchemaValidation and
    disableOpenAPIValidation by @allenporter in #856
  - Remove unnecessary slugify dependency by @filipposc5 in #849
  * Developer updates
  - Update tag to avoid drifting repo by @allenporter in #852
  - chore(deps): update dependency ruff to v0.10.0 by @renovate
    in #850
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.10.0 by @renovate in #851
  - chore(deps): update dependency yamllint to v1.36.0 by
    @renovate in #846
  - chore(deps): update pre-commit hook adrienverge/yamllint to
    v1.36.0 by @renovate in #847
  - chore(deps): update docker.io/bitnami/kubectl docker tag to
    v1.32.3 by @renovate in #848
* Thu Mar  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.2.1:
  * What's Changed
  - Make OCI chartRef work with optional namespace by @Alexsaphir
    in #844
* Wed Mar  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.2.0:
  * What's Changed
  - Fix OCIRepository support in get cluster by @allenporter in
    [#843]
  - Detect more images from commonly used crds by @buroa in #833
* Wed Mar  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.1.0:
  * What's Changed
  - fix: remove kubectl from Dockefile by @onedr0p in #822
  - Add get cluster --only-images flag to limit output by
    @allenporter in #835
  - Add --output=json for most commands by @allenporter in #836
  - Add label selector in internal code that walks the repo and
    matches Kustomization and HelmReleases by @allenporter in
    [#837]
  - Add --label-selector command line flags by @allenporter in
    [#839]
  - Add a flag --skip-kinds to omit kind from the output by
    @allenporter in #840
  - Pass OCIRepository chart ref tag to helm --version by
    @allenporter in #841
  * Developer updates
  - chore(deps): update dependency pip to v25 by @renovate in
    [#825]
  - feat(actions): bump actions/setup-python to v5 by @layertwo
    in #827
  - chore(deps): update pre-commit hook psf/black to v25 by
    @renovate in #829
  - chore(deps): update dependency black to v25 by @renovate in
    [#828]
* Fri Jan  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.0.0:
  * Breaking changes
    This release removes kyverno support. All references to command
    line options and action options related to kyverno have been
    removed and you need to remove them when upgrading. It is
    expected this feature was rarely used (and as a result, not
    worth the effort to maintain).
  * What's Changed
    There is a change to dependency tracking for HelmReleases that
    is meant to catch changes in dependencies that were previously
    ignored. Please report an issue if you see unexpected
    HelmRelease diffs.
  - Remove kyverno support by @allenporter in #818
  - Move resource diff and visitor logic to primary library
    directory by @allenporter in #819
  - Update testdata to remove invalid dependsOn reference in
    cluster8 by @allenporter in #820
  - Improve HelmRelease dependency tracking for diffs by
    @allenporter in #821
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.1.1:
  * What's Changed
  - Fix merging of values to override inline values last broken in 6.1.0 1
    by @allenporter in #815
  * Developer updates
  - Update devcontainer Dockerfile to jammy 20241217 by @allenporter in #814
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.1.0:
  * What's Changed
  - Add deep-merge of values, and allow empty values file by
    @Lingkar in #812
  * Developer updates
  - Upgrade to python 3.13 by @allenporter in #804
  - chore(deps): update codecov/codecov-action action to v5 by
    @renovate in #805
  - Apply cruft updates by @allenporter in #809
  - Apply cruft updates by @allenporter in #810
  - chore(deps): update dependency pdoc to v15.0.1 by @renovate
    in #811
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.6.2:
  * What's Changed
  - Strip attributes in List resources by @allenporter in #802
  * Developer updates
  - chore(deps): update dependency pytest-cov to v6 by @renovate
    in #800
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.0.1:
  * What's Changed
  - Set unique placeholder values for each substitution by
    @allenporter in #801
  * Developer updates
  - chore(deps): update dependency pdoc to v15 by @renovate in
    [#799]
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.0.0:
  * Breaking Changes
  - This is a breaking change that updates the format of the flux
    build command to have parity with get and diff commands.
    Example to build a single kustomziation:
    $ flux-local build ks apps --path tests/testdata/cluster/
    Example to inflate a single helm release:
    $ flux-local build hr podinfo -n podinfo --path tests/testdata/cluster
    The old behavior flux-local build tests/testdata/cluster/ can
    still be achieved with build all:
    $ flux-local build all tests/testdata/cluster/
  * What's Changed
  - chore(deps): update dependency types-pyyaml to
    v6.0.12.20240808 by @renovate in #774
  - chore(deps): update dependency ruff to v0.5.7 by @renovate in
    [#775]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.5.7 by @renovate in #776
  - chore(deps): update docker.io/bitnami/kubectl docker tag to
    v1.31.0 by @renovate in #777
  - chore(deps): update dependency ruff to v0.6.0 by @renovate in
    [#778]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.0 by @renovate in #779
  - chore(deps): update dependency ruff to v0.6.1 by @renovate in
    [#780]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.1 by @renovate in #781
  - chore(deps): update ubuntu docker tag to jammy-20240808 by
    @renovate in #782
  - chore(deps): update docker.io/alpine/helm docker tag to
    v3.15.4 by @renovate in #783
  - chore(deps): update codespell-project/actions-codespell
    action to v2.1 by @renovate in #784
  - chore(deps): update dependency syrupy to v4.6.4 by @renovate
    in #785
  - chore(deps): update dependency pytest-asyncio to v0.24.0 by
    @renovate in #786
  - chore(deps): update dependency ruff to v0.6.2 by @renovate in
    [#787]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.2 by @renovate in #788
  - chore(deps): update dependency syrupy to v4.7.1 by @renovate
    in #789
  - chore(deps): update dependency mypy to v1.11.2 by @renovate
    in #790
  - chore(deps): update peter-evans/create-pull-request action to
    v7 by @renovate in #791
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.4 by @renovate in #793
  - chore(deps): update dependency ruff to v0.6.4 by @renovate in
    [#792]
  - chore(deps): update dependency pdoc to v14.7.0 by @renovate
    in #794
  - chore(deps): update dependency pre-commit to v4 by @renovate
    in #796
  - chore(deps): update pre-commit hook
    pre-commit/pre-commit-hooks to v5 by @renovate in #797
  - Update flux build to have parity with other flux commands by
    @allenporter in #798
* Tue Sep 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-flux-local: set of tools and libraries for
  managing a local flux gitops repository
